==> jangaroo-sdk-0.9.3.zip: joo/classes/ext/config/rowselectionmodel.js <==
joo.classLoader.prepare("package ext.config",/* {*/


/**
 * The default SelectionModel used by <a href="Ext.grid.GridPanel.html">Ext.grid.GridPanel</a>. It supports multiple selections and keyboard selection/navigation. The objects stored as selections and returned by <a href="output/Ext.grid.RowSelectionModel.html#Ext.grid.RowSelectionModel-getSelected">getSelected</a>, and <a href="output/Ext.grid.RowSelectionModel.html#Ext.grid.RowSelectionModel-getSelections">getSelections</a> are the <a href="Ext.data.Record.html">Record</a>s which provide the data for the selected rows.
 *
 * <p>This class serves as a
 * typed config object for constructor of class RowSelectionModel.</p>
 *
 * <p>Copyright &#169; 2011 Sencha Inc.</p>
 * @see ext.grid.RowSelectionModel
 */
{ExtConfig:{target:"ext.grid.RowSelectionModel"}},
"public class rowselectionmodel extends ext.config.abstractselectionmodel",4,function($$private){;return[ 

  "public function rowselectionmodel",function rowselectionmodel$(config/*:Object = null*/) {if(arguments.length<1){config = null;}

    ext.config.abstractselectionmodel.call(this,config);
  },


  /**
   <tt>false</tt> to turn off moving the editor to the next row down when the enter key is pressed or the next row up when shift + enter keys are pressed.
   */
  "public native function get moveEditorOnEnter"/*():Boolean*/,

  /**
   * @private
   */
  "public native function set moveEditorOnEnter"/*(value:Boolean):void*/,

  /**
   <tt>true</tt> to allow selection of only one row at a time (defaults to <tt>false</tt> allowing multiple selections)
   */
  "public native function get singleSelect"/*():Boolean*/,

  /**
   * @private
   */
  "public native function set singleSelect"/*(value:Boolean):void*/,


];},[],["ext.config.abstractselectionmodel"], "0.8.0", "0.9.3"
);

==> jangaroo-sdk-0.9.13.zip: joo/classes/ext/config/rowselectionmodel.js <==
joo.classLoader.prepare("package ext.config",/* {*/


/**
 * The default SelectionModel used by <a href="Ext.grid.GridPanel.html">Ext.grid.GridPanel</a>. It supports multiple selections and keyboard selection/navigation. The objects stored as selections and returned by <a href="output/Ext.grid.RowSelectionModel.html#Ext.grid.RowSelectionModel-getSelected">getSelected</a>, and <a href="output/Ext.grid.RowSelectionModel.html#Ext.grid.RowSelectionModel-getSelections">getSelections</a> are the <a href="Ext.data.Record.html">Record</a>s which provide the data for the selected rows.
 *
 * <p>This class serves as a
 * typed config object for constructor of class RowSelectionModel.</p>
 *
 * <p>Copyright &#169; 2011 Sencha Inc.</p>
 * @see ext.grid.RowSelectionModel
 */
{ExtConfig:{target:"ext.grid.RowSelectionModel"}},
"public class rowselectionmodel extends ext.config.abstractselectionmodel",4,function($$private){var $1=ext.config;return[ 

  "public function rowselectionmodel",function rowselectionmodel(config/*:Object = null*/) {if(arguments.length<=0)config=null;

     $1.abstractselectionmodel.call(this,config);
  },


  /**
   <tt>false</tt> to turn off moving the editor to the next row down when the enter key is pressed or the next row up when shift + enter keys are pressed.
   */
  "public native function get moveEditorOnEnter"/*():Boolean*/,

  /**
   * @private
   */
  "public native function set moveEditorOnEnter"/*(value:Boolean):void*/,

  /**
   <tt>true</tt> to allow selection of only one row at a time (defaults to <tt>false</tt> allowing multiple selections)
   */
  "public native function get singleSelect"/*():Boolean*/,

  /**
   * @private
   */
  "public native function set singleSelect"/*(value:Boolean):void*/,


undefined];},[],["ext.config.abstractselectionmodel"], "0.8.0", "0.9.12"
);
